Struct mio::Event
[−]
[src]
pub struct Event {
// some fields omitted
}An readiness event returned by Poll.
Event represents the raw event that the OS-specific selector returned. An event can represent more than one kind (such as readable or writable) at a time.
These Event objects are created by the OS-specific concrete Selector when they have events to report.
Methods
impl Event
fn new(kind: Ready, token: Token) -> Event
Create a new Event.